@@ -23,8 +23,11 @@ def test_pl_si():
             continue
         if word[-2:] == "'s":
             continue
-        if word[-1] == 's':
-            continue
+#        if word[-1] == 's':
+#            continue
+        p.classical(False)
+        yield check_pl_si, p, word
+        p.classical(True)
         yield check_pl_si, p, word
 
 
